/**
 * PETALS - PETALS Services Platform. Copyright (c) 2006 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * -------------------------------------------------------------------------
 * $Id: MailBCImpl.java 154 25 sept. 06 ofabre $
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.bc.mail;

import javax.jbi.JBIException;

import org.ow2.petals.bc.mail.listeners.MailBCExternalListener;
import org.ow2.petals.bc.mail.listeners.MailBCJBIListener;
import org.ow2.petals.bc.mail.listeners.MailSessionManager;
import org.ow2.petals.bc.mail.listeners.MimeMessageManager;
import org.ow2.petals.bc.mail.listeners.SessionDescriptorBuilder;
import org.ow2.petals.component.framework.bc.AbstractBindingComponent;

/**
 * The Mail Binding Component.
 * <p>
 * It creates some sub components like :
 * <p>
 * the <b>{@link MailSessionManager}</b> used to manage session with mail
 * servers : create and open sessions, send and receive mails,
 * <p>
 * the <b>{@link MimeMessageManager}</b> used to process (reading or creating)
 * mail messages,
 * <p>
 * the <b>{@link SessionDescriptorBuilder}</b> used to extract information from
 * a Mail URI String,
 * <p>
 * the <b>{@link MailBCExternalListener}</b> used to manage listeners for
 * external mail addresses registered during SU deployment,
 * <p>
 * the <b>{@link MailBCJBIListener}</b> used to process incoming JBI messages
 * <p>
 * This class defines some Default Value for mail features like :
 * <p>
 * <b>SMTP</b> (25), <b>IMAP</b> (143) and <b>POP3</b> (110) default ports,
 * <p>
 * default mail folder (INBOX),
 * <p>
 * default mail checking period (60 seconds).
 * 
 * @author ofabre - EBM Websourcing
 * 
 */
public class MailBCImpl extends AbstractBindingComponent {

    protected MailSessionManager mailSessionManager;

    protected MimeMessageManager mimeMessageManager;

    protected SessionDescriptorBuilder sessionDescriptorBuilder;

    @Override
    protected void doInit() throws JBIException {
        this.sessionDescriptorBuilder = new SessionDescriptorBuilder(this.getLogger(), this);
        this.mimeMessageManager = new MimeMessageManager(this.getLogger(), this);
        this.mailSessionManager = new MailSessionManager(this.getLogger());
    }

    public MailSessionManager getMailSessionManager() {
        return this.mailSessionManager;
    }

    public MimeMessageManager getMimeMessageManager() {
        return this.mimeMessageManager;
    }

    public SessionDescriptorBuilder getSessionDescriptorBuilder() {
        return this.sessionDescriptorBuilder;
    }
}
