/**
 * PETALS - PETALS Services Platform. Copyright (c) 2007 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */
package org.ow2.petals.bc.mail;

import java.util.ArrayList;
import java.util.List;

import org.ow2.petals.component.framework.DefaultBootstrap;
import org.ow2.petals.component.framework.jbidescriptor.generated.Jbi;
import org.w3c.dom.Element;

/**
 * 
 * @author "Mathieu CARROLLE - eBM WebSourcing"
 * 
 */
public class MailBootstrap extends DefaultBootstrap {

    @Override
    protected List<String> getAttributeList() {
        final List<String> attributes = new ArrayList<String>();
        attributes.add(Constants.HOST_PATHELEMENT);
        attributes.add(Constants.PORT_PATHELEMENT);
        attributes.add(Constants.USER_PATHELEMENT);
        attributes.add(Constants.PASSWORD_PATHELEMENT);
        return attributes;
    }

    /**
     * Get the smtp host value
     */
    public String getHost() {
        return this.getParam(Constants.HOST_PATHELEMENT);
    }

    /**
     * Get a mail parameter.
     * 
     * @param key
     * @param value
     * @param jbi
     */
    private String getParam(final String key) {
        final Jbi jbi = this.getJbiComponentConfiguration();
        String param = null;
        for (final Element element : jbi.getComponent().getAny()) {
            if (element.getLocalName().equals(key)) {
                param = element.getTextContent();
                break;
            }
        }
        return param;
    }

    /**
     * Get smtp password
     * 
     * @return
     */
    public String getPassword() {
        return this.getParam(Constants.PASSWORD_PATHELEMENT);
    }

    /**
     * Get smtp port
     * 
     * @return
     */
    public String getPort() {
        return this.getParam(Constants.PORT_PATHELEMENT);
    }

    /**
     * Get smtp username
     * 
     * @return
     */
    public String getUser() {
        return this.getParam(Constants.USER_PATHELEMENT);
    }

    /**
     * Set the Smtp host.
     * 
     * @param host
     */
    public void setHost(final String host) {
        this.setParam(Constants.HOST_PATHELEMENT, host);
    }

    /**
     * Set mail parameter
     * 
     * @param key
     * @param value
     * @param jbi
     */
    private void setParam(final String key, final String value) {
        final Jbi jbi = this.getJbiComponentConfiguration();
        for (final Element element : jbi.getComponent().getAny()) {
            if (element.getLocalName().equals(key)) {
                element.setTextContent(value);
            }
        }
    }

    /**
     * Set smtp password
     * 
     * @param password
     */
    public void setPassword(final String password) {
        this.setParam(Constants.PASSWORD_PATHELEMENT, password);
    }

    /**
     * Set smtp port
     * 
     * @param port
     */
    public void setPort(final String port) {
        this.setParam(Constants.PORT_PATHELEMENT, port);
    }

    /**
     * Set smtp username
     * 
     * @param user
     */
    public void setUser(final String user) {
        this.setParam(Constants.USER_PATHELEMENT, user);
    }
}
