/**
 * PETALS - PETALS Services Platform. Copyright (c) 2006 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * -------------------------------------------------------------------------
 * $Id: MailBCJBIListener.java 154 27 sept. 06 ofabre $
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.bc.mail.listeners;

import java.util.logging.Level;

import javax.jbi.JBIException;
import javax.mail.MessagingException;
import javax.mail.Session;
import javax.mail.internet.MimeMessage;

import org.ow2.easywsdl.wsdl.api.WSDLException;
import org.ow2.petals.bc.mail.MailBCImpl;
import org.ow2.petals.bc.mail.MissingElementException;
import org.ow2.petals.bc.mail.service.SendMailGenericService;
import org.ow2.petals.component.framework.api.configuration.ConfigurationExtensions;
import org.ow2.petals.component.framework.api.message.Exchange;
import org.ow2.petals.component.framework.listener.AbstractJBIListener;
import org.ow2.petals.component.framework.util.UtilFactory;

/**
 * Mail BC listener for incoming JBI messages
 * 
 * @author ofabre - EBM Websourcing
 * @author "Mathieu CARROLLE - eBM WebSourcing"
 * 
 */
public class MailBCJBIListener extends AbstractJBIListener {

    protected MailSessionManager mailSessionManager;

    protected MimeMessageManager mimeMessageManager;

    protected SessionDescriptorBuilder sessionDescriptorBuilder;

    protected SendMailGenericService sendMailService;

    @Override
    public void init() {
        this.mimeMessageManager = ((MailBCImpl) this.getComponent()).getMimeMessageManager();
        this.mailSessionManager = ((MailBCImpl) this.getComponent()).getMailSessionManager();
        this.sessionDescriptorBuilder = ((MailBCImpl) this.getComponent())
                .getSessionDescriptorBuilder();
        this.sendMailService = new SendMailGenericService(this.mailSessionManager,
                this.mimeMessageManager, this.sessionDescriptorBuilder, this.getLogger());
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * org.objectweb.petals.component.common.bc.JBIListener#onJBIMessage(java
     * .lang.String,
     * org.objectweb.petals.component.common.util.MessageExchangeWrapper,
     * org.objectweb.petals.tools.jbicommon.descriptor.Extensions)
     */
    @Override
    public boolean onJBIMessage(final Exchange exchange) {

        // Fault ignored
        if (exchange.getFault() == null) {
            try {
                if (UtilFactory.getWSDLUtil().isDescriptionContaining(
                        this.component.getNativeWsdl().getDescription(), exchange.getEndpoint())) {
                    this.sendMailService.sendMailGenericService(exchange);
                } else {
                    this.standardSendService(exchange);
                }
            } catch (final WSDLException e) {
                this.getLogger().warning("Error on wsdl reading: " + e.getMessage());
            } catch (final JBIException e) {
                this.getLogger().log(Level.WARNING,
                        e.getClass().getSimpleName() + " : " + e.getMessage());
                exchange.setError(new Exception(e));
            }
        }
        return true;
    }

    /**
     * Standard service : send the jbi message content as an email<br>
     * the email address and subject are defined in the service unit
     * 
     * @param exchange
     * @throws JBIException
     */
    protected void standardSendService(final Exchange exchange) throws JBIException {
        try {
            this.getLogger().log(Level.INFO, "JBI Exchange received - send it as a mail");
            final ConfigurationExtensions extensions = this.getExtensions();

            // Build a mail session descriptor from the given address (URI)
            SessionDescriptor sessionDescriptor;

            sessionDescriptor = this.sessionDescriptorBuilder.build(extensions);

            // Build the mail session
            final Session session = this.mailSessionManager
                    .createSessionPropertiesFromDescriptor(sessionDescriptor);

            // Create a mail message with the incoming jbi message
            final MimeMessage mimeMessage = this.mimeMessageManager
                    .mapNormalizedMessageToMimeMessage(session, sessionDescriptor, exchange
                            .getInMessage());

            // Send this mail
            this.mailSessionManager.sendMail(mimeMessage, sessionDescriptor, session);

            this.getLogger().log(Level.INFO, "email sent to " + sessionDescriptor.getToAddress());

        } catch (final MissingElementException missingException) {
            this.getLogger().warning(
                    "Service unit send mail service : Missing element in the jbi.xml of the su  : "
                            + missingException.getElement());
            if (!exchange.isInOnlyPattern()) {
                this.sessionDescriptorBuilder.setMissingElementFaultOnExchange(exchange,
                        missingException.getElement());
            }
        } catch (final MessagingException me) {
            this.getLogger().log(Level.WARNING, "sendMail can not send the mail", me);
            if (!exchange.isInOnlyPattern()) {
                this.sessionDescriptorBuilder.setIOFaultOnExchange(exchange, me.getMessage());
            }
        }
    }
}
